/***********************************************************
 * @Description : 考试详情的实体类
 * @author      : 梁山广(Laing Shan Guang)
 * @date        : 2019-06-24 08:14
 * @email       : liangshanguang2@gmail.com
 ***********************************************************/
package lsgwr.exam.vo;
// 引入Exam实体类，它可能包含了考试的详细信息，如考试ID、名称、描述等
import lsgwr.exam.entity.Exam;
// 引入Lombok库的@Data注解，用于自动生成getter、setter等方法
import lombok.Data;
// 使用@Data注解来自动生成这个类的getter、setter等方法
@Data
public class ExamDetailVo {
    /**
     * 考试的基本信息对象。
     * 这个字段存储了一个Exam类型的对象，该对象可能包含了考试的详细信息，
     * 如考试ID、名称、描述、时长、状态等。
     * 这里，ExamDetailVo通过持有这个Exam对象来提供关于特定考试的详细信息。
     */
    private Exam exam;

    /**
     * 单选题的id数组。
     * 这个字段是一个字符串数组，用于存储考生所选的单选题的ID。
     * 每个字符串可能代表一个单选题的唯一标识符。
     * 在处理考试结果或进行成绩统计时，这些ID可以用于查找和验证考生所选的答案。
     */
    private String[] radioIds;

    /**
     * 多选题的id数组。
     * 类似于单选题的id数组，这个字段存储了考生所选的多选题的ID。
     * 由于多选题可能允许选择多个选项，因此这个数组可能包含多个字符串，
     * 每个字符串代表一个被选中的多选题的唯一标识符。
     */
    private String[] checkIds;

    /**
     * 判断题的id数组。
     * 这个字段也是一个字符串数组，用于存储考生所选的判断题的ID。
     * 每个字符串代表一个判断题的唯一标识符，通常与考生所选的答案（正确或错误）相关联。
     * 在处理考试结果时，这些ID可以用于查找和验证考生对判断题的回答。
     */
    private String[] judgeIds;

}
